Signature

Struct Signature 

pub struct Signature { /* private fields */ }
Taproot Schnorr signature as defined in BIP340.

Implementations

Source

impl Signature

pub const BYTE_SIZE: usize = 64

Size of a Taproot Schnorr signature in bytes.

pub fn to_bytes(&self) -> SignatureBytes

Serialize this signature as bytes.

pub fn from_bytes(bytes: &SignatureBytes) -> Result<Self>

Parse a Taproot Schnorr from a byte array.

Errors

Returns Error if the signature failed to parse successfully.

pub fn from_slice(bytes: &[u8]) -> Result<Self>

Parse a Taproot Schnorr from a byte slice.

Errors

Returns Error if bytes is not 64-bytes (i.e. Signature::BYTE_SIZE) long or if it otherwise failed to parse successfully.