SigningKey

Struct SigningKey 

pub struct SigningKey { /* private fields */ }
Taproot Schnorr signing key.

Implementations

Source

impl SigningKey

pub fn from_bytes(bytes: &FieldBytes) -> Result<Self>

Parse signing key from big endian-encoded bytes.

Errors

Returns Error in the event the provided bytes overflow the curve order n.

pub fn from_slice(bytes: &[u8]) -> Result<Self>

Parse signing key from big endian-encoded byte slice.

Errors

Returns Error if bytes is not 32-bytes long, or if it overflows the curve order n.

pub fn to_bytes(&self) -> FieldBytes

Serialize as bytes.

pub fn verifying_key(&self) -> &VerifyingKey

Get the VerifyingKey that corresponds to this signing key.

pub fn as_nonzero_scalar(&self) -> &NonZeroScalar

Borrow the secret NonZeroScalar value for this key.

Security Warning

This value is key material. Please treat it with the care it deserves!

pub fn random<R: CryptoRng + ?Sized>(rng: &mut R) -> Self

👎Deprecated since 0.14.0:

use the Generate trait instead

Deprecated: Generate a cryptographically random SigningKey.