pub struct VerifyingKey { /* private fields */ }Expand description
Taproot Schnorr verifying key.
Implementations
Sourceimpl VerifyingKey
impl VerifyingKey
Sourcepub fn from_bytes(x_bytes: &FieldBytes) -> Result<Self>
pub fn from_bytes(x_bytes: &FieldBytes) -> Result<Self>
Parse verifying key from big endian-encoded x-coordinate.
Errors
Returns an error if a curve point could not be reconstructed from x_bytes.
Sourcepub fn from_slice(x_bytes: &[u8]) -> Result<Self>
pub fn from_slice(x_bytes: &[u8]) -> Result<Self>
Parse verifying key from big endian-encoded x-coordinate.
Errors
Returns an error if x_bytes is not 32-bytes long or if a valid curve point could not
be reconstructed.
Sourcepub fn as_affine(&self) -> &AffinePoint
pub fn as_affine(&self) -> &AffinePoint
Borrow the inner AffinePoint this type wraps.
Sourcepub fn to_bytes(&self) -> FieldBytes
pub fn to_bytes(&self) -> FieldBytes
Serialize as bytes.
Sourcepub fn verify_raw(&self, message: &[u8], signature: &Signature) -> Result<()>
pub fn verify_raw(&self, message: &[u8], signature: &Signature) -> Result<()>
Compute Schnorr signature.
This is a low-level interface intended only for unusual use cases involving verifying pre-hashed messages, or “raw” messages where the message is not hashed at all prior to being used to generate the Schnorr signature.
The preferred interfaces are the DigestVerifier or PrehashVerifier traits.
Errors
Returns Error if signature is not valid for message.